@@ -3,6 +3,7 @@ KEY__last_totp = "last_totp"
 KEY__application = "application"
 KEY__application_description = "application_description"
 KEY__configuration = "configuration"
+KEY__configuration_name = "name"
 KEY__configuration_description = "configuration_description"
 KEY__exception = "exception"
 KEY__install_key = "install_key"
@@ -18,9 +19,12 @@ KEY__sort = "sort"
 KEY__invite_key = "invite_key"
 KEY__search = "search"
 KEY__parameter_name = "parameter_name"
+KEY__application_name = "name"
+KEY__parameter = "parameter"
 KEY__parameter_description = "parameter_description"
 KEY__size = "size"
 KEY__database = "database"
+KEY__node_name = "name"
 KEY__authorization = "authorization"
 KEY__argument = "argument"
 KEY__is_node = "is_node"
@@ -37,7 +41,9 @@ KEY__page = "page"
 KEY__show_deleted = "show_deleted"
 KEY__description = "description"
 KEY__database_name = "name"
-KEY__node_name = "name"
+KEY__create = "create"
+KEY__drop = "drop"
+KEY__force_transactional = "force_transactional"
 KEY__port = "port"
 KEY__address = "address"
 KEY__jaaql_name = "jaaql_name"
@@ -80,4 +86,4 @@ JAAQL__arg_marker = ":"
 ENCODING__utf = "UTF-8"
 EXAMPLE__jwt = "eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.e30.yXvILkvUUCBqAFlAv6wQ1Q-QRAjfe3eSosO949U73Vo"
 
-VERSION = "2.0.0"
+VERSION = "2.1.2"
