@@ -1,12 +1,53 @@
 from jaaql.openapi.swagger_documentation import *
 from jaaql.constants import *
-from jaaql.documentation.documentation_shared import ARG_RES__jaaql_password, ARG_RES__totp_mfa, ARG_RES__email,\
-    JWT__invite, gen_arg_res_sort_pageable, gen_filtered_records, ARG_RES__deletion_key, RES__deletion_key
+from jaaql.documentation.documentation_shared import ARG_RES__jaaql_password, ARG_RES__email,\
+    JWT__invite, gen_arg_res_sort_pageable, gen_filtered_records, ARG_RES__deletion_key, RES__deletion_key,\
+    set_nullable, rename_arg, ARG_RES__database_name, EXAMPLE__db, ARG_RES__application_name,\
+    EXAMPLE__application_name, EXAMPLE__application_url, ARG_RES__application_body
 
 TITLE = "JAAQL Internal API"
 DESCRIPTION = "Collection of methods in the JAAQL internal API"
 FILENAME = "jaaql_internal_api"
 
+ARG_RES__double_mfa = SwaggerResponse(
+    description="Contains information to setup authenticator app for jaaql and potentially postgres user",
+    response=[
+        SwaggerArgumentResponse(
+            name=KEY__jaaql_otp_uri,
+            description="OTP URI for the jaaql user",
+            arg_type=str,
+            example=["otpauth://totp/%test?secret=supersecret&issuer=JAAQL",
+                     "otpauth://totp/%mylabel?secret=pa55word&issuer=MyIssuer"],
+            required=True
+        ),
+        SwaggerArgumentResponse(
+            name=KEY__jaaql_otp_qr,
+            description="OTP QR code for the jaaql user, as a inlined base64 encoded png image",
+            arg_type=str,
+            example=["data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAKsAAADV...",
+                     "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAUA..."],
+            required=True
+        ),
+        SwaggerArgumentResponse(
+            name=KEY__superjaaql_otp_uri,
+            description="OTP URI for the superjaaql user",
+            arg_type=str,
+            example=["otpauth://totp/%test?secret=supersecret&issuer=JAAQL",
+                     "otpauth://totp/%mylabel?secret=pa55word&issuer=MyIssuer"],
+            required=False,
+            condition="Was the superjaaql password supplied"
+        ),
+        SwaggerArgumentResponse(
+            name=KEY__superjaaql_otp_qr,
+            description="OTP QR code for the superjaaql user, as a inlined base64 encoded png image",
+            arg_type=str,
+            example=["data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAKsAAADV...",
+                     "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAUA..."],
+            required=False,
+            condition="Was the superjaaql password supplied"
+        )
+    ]
+)
 
 DOCUMENTATION__install = SwaggerDocumentation(
     tags="Installation",
@@ -14,7 +55,8 @@ DOCUMENTATION__install = SwaggerDocumentation(
     methods=SwaggerMethod(
         name="Install JAAQL",
         description="Installs JAAQL to the configured database. Please allow a minute after running for the server to "
-        "refresh and reload",
+        "refresh and reload. A connection string is required for local installation and is not allowed when running "
+        "inside a docker container as the docker container comes with a postgres database and JAAQL will use that",
         method=REST__POST,
         body=[
             SwaggerArgumentResponse(
@@ -23,7 +65,8 @@ DOCUMENTATION__install = SwaggerDocumentation(
                 arg_type=str,
                 example=["postgresql://postgres:123456@localhost:5432/jaaql",
                          "postgresql://postgres:pa55word@localhost:5432/jaaql"],
-                required=True
+                required=True,
+                local_only=True
             ),
             ARG_RES__jaaql_password,
             SwaggerArgumentResponse(
@@ -32,92 +75,61 @@ DOCUMENTATION__install = SwaggerDocumentation(
                 arg_type=str,
                 example=["aefc1b08-a573-466f-bdd0-706ae281cc99", "ec63aa9a-b189-419f-8e0b-7fcc4ff8c857"],
                 required=True
+            ),
+            SwaggerArgumentResponse(
+                name=KEY__superjaaql_password,
+                description="At the postgres level, the postgres user is used to set up the jaaql user. If you want "
+                "access to the postgres user through JAAQL, please provide a password and this user will be setup for "
+                "you. This is a JAAQL login for superjaaql so it is entirely independent of the postgres password "
+                "at the database level. If you do not supply this password, you will not be able to login to jaaql "
+                "authenticating as postgres with the local database node. You can set this up later if you want ",
+                example=["sup3rjaaqlpa55word"],
+                condition="If you want to give the superjaaql user a login",
+                required=False,
+                arg_type=str
             )
         ],
-        response=ARG_RES__totp_mfa
+        response=[
+            ARG_RES__double_mfa,
+            SwaggerFlatResponse(
+                description=ERR__already_installed,
+                code=HTTPStatus.UNPROCESSABLE_ENTITY,
+                body=ERR__already_installed
+            )
+        ]
     )
 )
 
 # Not unused. Used to generate html files
-from jaaql.documentation.documentation_shared import DOCUMENTATION__oauth_token, DOCUMENTATION__oauth_refresh
+from jaaql.documentation.documentation_shared import DOCUMENTATION__login_details, DOCUMENTATION__oauth_token,\
+    DOCUMENTATION__oauth_refresh
 
-KEY__application_name = "name"
-EXAMPLE__application_name = "Library Browser"
-KEY__application_url = "url"
-EXAMPLE__application_url = "https://jaaql.com/demos/library-application"
 
-ARG_RES__application_name = SwaggerArgumentResponse(
-    name=KEY__application_name,
-    description="Application name",
-    arg_type=str,
-    example=[EXAMPLE__application_name, "Meeting Room Scheduling Assistant"],
-    required=True
-)
-ARG_RES__application_description = SwaggerArgumentResponse(
-    name="description",
-    description="Application description",
-    arg_type=str,
-    example=["Browses books in the library", "Helps book meetings"],
-    required=True
-)
-ARG_RES__application_uri = SwaggerArgumentResponse(
-    name=KEY__application_url,
-    description="Application url",
-    arg_type=str,
-    example=[EXAMPLE__application_url, "https://jaaql.com/demos/meeting-application"],
-    required=True
-)
-
-EXAMPLE__db = "library"
 EXAMPLE__address = "mydb.abbcdcec9afd.eu-west-1.rds.amazonaws.com"
 
-KEY__is_console_level = "is_console_level"
+EXAMPLE__node_label = "lion"
+ARG_RES__node_label = SwaggerArgumentResponse(
+    name=KEY__node_name,
+    description="The label of the node, provides real world semantic meaning",
+    arg_type=str,
+    example=[EXAMPLE__node_label],
+    required=True
+)
 
-ARG_RES__database_base = [
-    SwaggerArgumentResponse(
-        name=KEY__database_name,
-        description="The name of the database on the database server",
-        arg_type=str,
-        example=[EXAMPLE__db, "meetings"],
-        required=True
-    ),
-    SwaggerArgumentResponse(
-        name=KEY__description,
-        description="Description of the database",
-        arg_type=str,
-        example=["The library database on PROD", "The meeting database on QA"],
-        required=True
-    ),
+ARG_RES__node_base = [
     SwaggerArgumentResponse(
         name=KEY__port,
-        description="Port on which the database runs",
+        description="Port on which the node runs",
         arg_type=int,
         example=[5432, 3306],
         required=True
     ),
     SwaggerArgumentResponse(
         name=KEY__address,
-        description="Database host",
+        description="Node host address",
         arg_type=str,
         example=[EXAMPLE__address, "184.219.247.60"],
         required=True
-    ),
-    SwaggerArgumentResponse(
-        name=KEY__jaaql_name,
-        description="The internal name of the database",
-        arg_type=str,
-        example=["Library database PROD", "Meeting database QA"],
-        required=True
-    ),
-    SwaggerArgumentResponse(
-        name=KEY__is_console_level,
-        description="Set to true if the database can be overwrote on a submit command with the db_name argument. "
-        "For example, if the argument '" + KEY__database_name + "' is set to public and the db_name argument is set "
-        "with sqmi on submit, the queries will be executed against the sqmi database. We recommend leaving on False",
-        condition="If missing, set to false",
-        arg_type=bool,
-        example=[False, True],
-        required=False
     )
 ]
 
@@ -125,52 +137,127 @@ ARG_RES__deleted = SwaggerArgumentResponse(
     name=KEY__show_deleted,
     description="Show deleted. If true will return all, deleted or not",
     condition="If not supplied will return only those not marked as deleted",
+    required=False,
     arg_type=bool,
     example=[True, False]
 )
 
 ARG_RES__when_deleted = SwaggerArgumentResponse(
     name=ATTR__deleted,
-    description="The timestamp at which the database was deleted (if deleted)",
+    description="The timestamp at which the item was deleted (if deleted)",
     condition="Requested view of deleted. Null if requested and not deleted",
     arg_type=str,
+    required=False,
     example=["2021-08-07 19:05:07.763189+01:00", "2021-08-07 18:04:41.156935+01:00"]
 )
 
+DOCUMENTATION__nodes = SwaggerDocumentation(
+    tags="Nodes",
+    methods=[
+        SwaggerMethod(
+            name="Add node",
+            description="Adds a new node",
+            body=[set_nullable(ARG_RES__node_label, condition="If not provided will be automatically generated")] +
+                 ARG_RES__node_base + [
+                SwaggerArgumentResponse(
+                    name=KEY__description,
+                    description="Description of the node",
+                    arg_type=str,
+                    condition="Imputed from the node name if not required",
+                    example=["The PROD library node", "The office QA node"],
+                    required=False,
+                )
+            ],
+            method=REST__POST
+        ),
+        SwaggerMethod(
+            name="Fetch nodes",
+            description="Fetch a list of nodes",
+            method=REST__GET,
+            arguments=gen_arg_res_sort_pageable(KEY__node_name, KEY__address, EXAMPLE__node_label, EXAMPLE__address),
+            response=SwaggerResponse(
+                description="List of nodes",
+                response=gen_filtered_records(
+                    KEY__node,
+                    [
+                        ARG_RES__node_label
+                    ] + ARG_RES__node_base + [
+                        SwaggerArgumentResponse(
+                            name=KEY__description,
+                            description="Description of the node",
+                            arg_type=str,
+                            example=["The PROD library node", "The office QA node"],
+                            required=True,
+                        ),
+                        ARG_RES__when_deleted
+                    ]
+                )
+            )
+        ),
+        SwaggerMethod(
+            name="Delete node",
+            description="Deletes a node",
+            method=REST__DELETE,
+            arguments=ARG_RES__node_label,
+            response=RES__deletion_key
+        )
+    ]
+)
+
+DOCUMENTATION__nodes_confirm_deletion = SwaggerDocumentation(
+    tags="Nodes",
+    methods=SwaggerMethod(
+        name="Confirm node deletion",
+        description="Confirm the node deletion, providing a single use deletion key",
+        method=REST__POST,
+        body=ARG_RES__deletion_key
+    )
+)
+
+ARG_RES__reference_node = rename_arg(ARG_RES__node_label, KEY__node)
+
+ARG_RES__database_base = [
+    ARG_RES__database_name,
+    ARG_RES__reference_node
+]
+
+ARG_RES__database_create = SwaggerArgumentResponse(
+    name=KEY__create,
+    description="Whether or not to create the database on the node",
+    arg_type=bool,
+    example=[True],
+    required=True
+)
+
+ARG_RES__database_drop = SwaggerArgumentResponse(
+    name=KEY__drop,
+    description="Whether or not to drop the database on the node",
+    arg_type=bool,
+    example=[True],
+    required=True
+)
+
 DOCUMENTATION__databases = SwaggerDocumentation(
     tags="Databases",
     methods=[
         SwaggerMethod(
             name="Add Database",
             description="Add a new database",
-            arguments=ARG_RES__database_base,
-            method=REST__POST,
-            response=SwaggerFlatResponse(
-                description="The database UUID",
-                body="aaa901f2-fc92-4b8a-8a30-d35d36b9189e"
-            )
+            arguments=ARG_RES__database_base + [ARG_RES__database_create],
+            method=REST__POST
         ),
         SwaggerMethod(
             name="Fetch Databases",
             description="Fetch a list of databases",
             method=REST__GET,
-            arguments=gen_arg_res_sort_pageable(KEY__database_name, KEY__address, EXAMPLE__db, EXAMPLE__address) + [
+            arguments=gen_arg_res_sort_pageable(KEY__database_name, KEY__node, EXAMPLE__db, EXAMPLE__node_label) + [
                 ARG_RES__deleted
             ],
             response=SwaggerResponse(
                 description="List of databases",
                 response=gen_filtered_records(
-                    "database",
-                    [
-                        SwaggerArgumentResponse(
-                            name="id",
-                            description="The internal id of the database",
-                            arg_type=str,
-                            example=["177237b2-f85c-4a68-a5dc-5b2bdfbd0c73", "2edf1af1-8fb5-4f8a-86bd-081bdaafcf48"],
-                            required=True
-                        ),
-                        ARG_RES__when_deleted
-                    ] + ARG_RES__database_base
+                    KEY__database,
+                    [ARG_RES__when_deleted] + ARG_RES__database_base
                 )
             )
         ),
@@ -178,13 +265,7 @@ DOCUMENTATION__databases = SwaggerDocumentation(
             name="Delete Database",
             description="Deletes a database",
             method=REST__DELETE,
-            arguments=SwaggerArgumentResponse(
-                name="id",
-                description="Database id",
-                arg_type=str,
-                example=["177237b2-f85c-4a68-a5dc-5b2bdfbd0c73", "2edf1af1-8fb5-4f8a-86bd-081bdaafcf48"],
-                required=True
-            ),
+            arguments=[ARG_RES__reference_node, ARG_RES__database_name, ARG_RES__database_drop],
             response=RES__deletion_key
         )
     ]
@@ -207,11 +288,7 @@ DOCUMENTATION__applications = SwaggerDocumentation(
             name="Add application",
             description="Add a new application",
             method=REST__POST,
-            body=[
-                ARG_RES__application_name,
-                ARG_RES__application_description,
-                ARG_RES__application_uri
-            ]
+            body=ARG_RES__application_body
         ),
         SwaggerMethod(
             name="Fetch applications",
@@ -223,10 +300,7 @@ DOCUMENTATION__applications = SwaggerDocumentation(
                 description="List of applications",
                 response=gen_filtered_records(
                     "application",
-                    [
-                        ARG_RES__application_name,
-                        ARG_RES__application_description,
-                        ARG_RES__application_uri,
+                    ARG_RES__application_body + [
                         SwaggerArgumentResponse(
                             name="created",
                             description="Application creation timestamp",
@@ -301,15 +375,18 @@ ARG__application_name = SwaggerArgumentResponse(
 KEY__application_parameter_name = "name"
 EXAMPLE__application_parameter_db = "library_db"
 
+ARG_RES__application_parameter_name = SwaggerArgumentResponse(
+    name=KEY__application_parameter_name,
+    description="The name of the parameter",
+    arg_type=str,
+    example=[EXAMPLE__application_parameter_db, "meeting_db"],
+    required=True
+)
+ARG_RES__reference_application_parameter = rename_arg(ARG_RES__application_name, KEY__parameter)
+
 ARG_RES__application_parameter_key = [
     ARG__application_name,
-    SwaggerArgumentResponse(
-        name=KEY__application_parameter_name,
-        description="The name of the parameter",
-        arg_type=str,
-        example=[EXAMPLE__application_parameter_db, "meeting_db"],
-        required=True
-    )
+    ARG_RES__application_parameter_name
 ]
 
 ARG_RES__application_parameter = ARG_RES__application_parameter_key + [
@@ -322,9 +399,17 @@ ARG_RES__application_parameter = ARG_RES__application_parameter_key + [
     )
 ]
 
-KEY__configuration_name = "name"
 EXAMPLE__configuration_name = "Library QA"
 
+ARG_RES__configuration_name = SwaggerArgumentResponse(
+    name=KEY__configuration_name,
+    description="The name of the configuration",
+    arg_type=str,
+    example=[EXAMPLE__configuration_name, "Meeting DEV"],
+    required=True
+)
+ARG_RES__reference_configuration = rename_arg(ARG_RES__configuration_name, KEY__configuration)
+
 ARG_RES__application_configuration_key = [
     SwaggerArgumentResponse(
         name=KEY__application,
@@ -333,13 +418,7 @@ ARG_RES__application_configuration_key = [
         example=[EXAMPLE__application_name, "Meeting Room"],
         required=True
     ),
-    SwaggerArgumentResponse(
-        name=KEY__configuration_name,
-        description="The name of the configuration",
-        arg_type=str,
-        example=[EXAMPLE__configuration_name, "Meeting DEV"],
-        required=True
-    )
+    ARG_RES__configuration_name
 ]
 
 ARG_RES__application_configuration = ARG_RES__application_configuration_key + [
@@ -440,34 +519,15 @@ DOCUMENTATION__application_configurations_confirm_deletion = SwaggerDocumentatio
 
 ARG_RES__application_argument_key = [
     ARG__application_name,
-    SwaggerArgumentResponse(
-        name=KEY__configuration,
-        description="The name of the configuration which this argument is associated with",
-        arg_type=str,
-        example=[EXAMPLE__configuration_name, "Meeting DEV"],
-        required=True
-    ),
-    SwaggerArgumentResponse(
-        name="parameter",
-        description="The name of the parameter which this argument is supplied for",
-        arg_type=str,
-        example=["library_db", "meeting_db"],
-        required=True
-    )
+    ARG_RES__reference_configuration,
+    ARG_RES__reference_application_parameter
 ]
 
-EXAMPLE__database = "0c44fc9b-d2de-4279-b686-1ce98f9a2ba4"
-
-ARG_RES__database = SwaggerArgumentResponse(
-    name=KEY__database,
-    description="The associated database argument",
-    arg_type=str,
-    example=[EXAMPLE__database, "a289ce95-2e46-4944-af19-72c9b75c717e"],
-    required=True
-)
+ARG_RES__reference_database = rename_arg(ARG_RES__database_name, KEY__database)
 
 ARG_RES__application_argument = ARG_RES__application_argument_key + [
-    ARG_RES__database
+    ARG_RES__reference_database,
+    ARG_RES__reference_node
 ]
 
 DOCUMENTATION__application_arguments = SwaggerDocumentation(
@@ -523,127 +583,126 @@ ARG_RES__role = SwaggerArgumentResponse(
     required=True
 )
 
-ARG_RES__authorization_application = [
+ARG_RES__authorization_configuration = [
     ARG__application_name,
+    ARG_RES__reference_configuration,
     ARG_RES__role
 ]
 
-DOCUMENTATION__authorization_application = SwaggerDocumentation(
+DOCUMENTATION__authorization_configuration = SwaggerDocumentation(
     tags="Authorization",
     methods=[
         SwaggerMethod(
-            name="Add application authorized role",
-            description="Add an authorized role to the application",
+            name="Add configuration authorized role",
+            description="Add an authorized role to the application configuration",
             method=REST__POST,
-            body=ARG_RES__authorization_application
+            body=ARG_RES__authorization_configuration
         ),
         SwaggerMethod(
-            name="Fetch Applications authorized Roles",
-            description="Fetch a list of roles which have been authorized to use application",
+            name="Fetch Configuration authorized Roles",
+            description="Fetch a list of roles which have been authorized to use an application configuration",
             method=REST__GET,
-            arguments=gen_arg_res_sort_pageable(KEY__application, KEY__role, EXAMPLE__application_name, EXAMPLE__role),
+            arguments=gen_arg_res_sort_pageable(KEY__configuration, KEY__role, EXAMPLE__configuration_name,
+                                                EXAMPLE__role),
             response=SwaggerResponse(
-                description="A list of roles authorized for an application",
+                description="A list of roles authorized for a configuration",
                 response=gen_filtered_records(
                     "application authorized role",
-                    ARG_RES__authorization_application
+                    ARG_RES__authorization_configuration
                 )
             )
         ),
         SwaggerMethod(
             name="Revoke role auth for application",
-            description="Requests the revoke of a role authorization for an application, returning a confirmation key",
+            description="Requests the revoke of a role authorization for an application configuration, returning a "
+            "confirmation key",
             method=REST__DELETE,
-            arguments=ARG_RES__authorization_application,
+            arguments=ARG_RES__authorization_configuration,
             response=RES__deletion_key
         )
     ]
 )
 
-DOCUMENTATION__authorization_application_confirm_deletion = SwaggerDocumentation(
+DOCUMENTATION__authorization_configuration_confirm_deletion = SwaggerDocumentation(
     tags="Authorization",
     methods=SwaggerMethod(
-        name="Confirm revoke of a role for an application",
-        description="Confirm the revoke of a role for an application, providing a single use deletion key",
+        name="Confirm revoke of a authorization configuration",
+        description="Confirm the revoke of a authorization for a configuration, providing a single use deletion key",
         method=REST__POST,
         body=ARG_RES__deletion_key
     )
 )
 
-ARG_RES__authorization_database_id = SwaggerArgumentResponse(
-    name="id",
-    description="The id of the authorized database",
-    arg_type=str,
-    example=["f6306777-e6c8-4c7c-ba68-8b6b4a0d4432", "1c9f6227-d72f-4ebe-9d64-f851b3d3419e"],
-    required=True
-)
-
-ARG_RES__authorization_database_input = [
-    ARG_RES__database,
-    ARG_RES__role,
+ARG_RES__authorization_node_credentials = [
     SwaggerArgumentResponse(
         name=KEY__username,
-        description="The username for the database",
+        description="The username for the node",
         arg_type=str,
         example=["postgres", "user"],
         required=True
     ),
     SwaggerArgumentResponse(
         name=KEY__password,
-        description="The password for the database",
+        description="The password for the node",
         arg_type=str,
         example=["123456", "pa55word"],
         required=True
     ),
-    SwaggerArgumentResponse(
-        name=KEY__precedence,
-        description="The precedence of the authorization. Higher overrides lower",
-        arg_type=int,
-        example=[0, 1],
-        required=False,
-        condition="Defaults to 0"
-    )
 ]
 
-DOCUMENTATION__authorization_database = SwaggerDocumentation(
+ARG_RES__authorization_node_key = [
+    ARG_RES__reference_node,
+    ARG_RES__role
+]
+
+ARG_RES__authorization_node_precedence = SwaggerArgumentResponse(
+    name=KEY__precedence,
+    description="The precedence of the authorization. Higher overrides lower",
+    arg_type=int,
+    example=[0, 1],
+    required=False,
+    condition="Defaults to 0"
+)
+
+DOCUMENTATION__authorization_node = SwaggerDocumentation(
     tags="Authorization",
     methods=[
         SwaggerMethod(
-            name="Add database authorization",
-            description="Add a database and it's credentials for use with a specific role",
+            name="Add node authorization",
+            description="Add a node and it's credentials for use with a specific role",
             method=REST__POST,
-            body=ARG_RES__authorization_database_input
+            body=ARG_RES__authorization_node_key + [ARG_RES__authorization_node_precedence] +
+                 ARG_RES__authorization_node_credentials,
         ),
         SwaggerMethod(
-            name="Fetch database authorizations",
-            description="Fetch a list of roles which have been authorized to use application",
+            name="Fetch node authorizations",
+            description="Fetch a list of roles which have been authorized to use nodes",
             method=REST__GET,
-            arguments=gen_arg_res_sort_pageable(KEY__database, KEY__role, EXAMPLE__database,
-                                                EXAMPLE__role) + [ARG_RES__deleted],
+            arguments=gen_arg_res_sort_pageable(KEY__node, KEY__role, EXAMPLE__node_label, EXAMPLE__role) + [
+                ARG_RES__deleted],
             response=SwaggerResponse(
-                description="A list of database authorizations and associated roles",
+                description="A list of node authorizations and associated roles",
                 response=gen_filtered_records(
-                    "database authorization",
-                    [ARG_RES__authorization_database_id] + ARG_RES__authorization_database_input + [
-                        ARG_RES__when_deleted]
+                    "node authorization",
+                    ARG_RES__authorization_node_key + [ARG_RES__authorization_node_precedence] + [ARG_RES__when_deleted]
                 )
             )
         ),
         SwaggerMethod(
-            name="Revoke role auth for database",
-            description="Requests the revoke of a database authorization, returning a confirmation key",
+            name="Revoke role auth for node",
+            description="Requests the revoke of a node authorization, returning a confirmation key",
             method=REST__DELETE,
-            arguments=ARG_RES__authorization_database_id,
+            arguments=ARG_RES__authorization_node_key,
             response=RES__deletion_key
         )
     ]
 )
 
-DOCUMENTATION__authorization_database_confirm_deletion = SwaggerDocumentation(
-    tags="Authorization",
+DOCUMENTATION__authorization_node_confirm_deletion = SwaggerDocumentation(
+    tags="Node Authorization",
     methods=SwaggerMethod(
-        name="Confirm revoke of a database authorization",
-        description="Confirm the revoke of a database authorization, providing a single use deletion key",
+        name="Confirm revoke of a node authorization",
+        description="Confirm the revoke of a node authorization, providing a single use deletion key",
         method=REST__POST,
         body=ARG_RES__deletion_key
     )
