@@ -1,5 +1,5 @@
 from jaaql.openapi.swagger_documentation import SwaggerDocumentation, SwaggerMethod, SwaggerArgumentResponse,\
-    SwaggerResponse, SwaggerList, SwaggerFlatResponse, REST__POST
+    SwaggerResponse, SwaggerList, SwaggerFlatResponse, REST__POST, REST__GET, SwaggerSimpleList
 from jaaql.constants import *
 
 OUTPUT = False
@@ -9,11 +9,21 @@ JWT__invite = "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJlbWFpbCI6ImFhcm9uQGphYXFs
 
 ENDPOINT__refresh = "/oauth/refresh"
 
+EXAMPLE__db = "meeting"
+ARG_RES__database_name = SwaggerArgumentResponse(
+    name=KEY__database_name,
+    description="The name of the database on the database server",
+    arg_type=str,
+    example=[EXAMPLE__db],
+    required=True
+)
+
 ARG_RES__deletion_key = SwaggerArgumentResponse(
     name=KEY__deletion_key,
     description="Single use deletion key",
     arg_type=str,
-    example=["eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJkZWxldGlvbl9wdXJwb3NlIjoiZXhhbXBsZSJ9.aJEPcEJBkyM9vEKT_D6AXT-hZAZ9UvagKGtljvsBj8w"],
+    example=["eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJkZWxldGlvbl9wdXJwb3NlIjoiZXhhbXBsZSJ9.aJEPcEJBkyM9vEKT_D6AXT-hZAZ"
+             "9UvagKGtljvsBj8w"],
     required=True
 )
 
@@ -153,21 +163,13 @@ ARG_RES__totp_mfa = SwaggerResponse(
     ]
 )
 
-ARG_RES__is_node = SwaggerArgumentResponse(
-    name=KEY__is_node,
-    description="Is the parameter a node or a database within a node",
-    arg_type=bool,
-    example=[True, False],
-    required=True
-)
-
 RES__oauth_token = SwaggerFlatResponse(
     description="A temporary JWT token that can be used to authenticate with the server",
     body=EXAMPLE__jwt
 )
 
 ARG_RES__mfa_key = SwaggerArgumentResponse(
-    name="mfa_key",
+    name=KEY__mfa_key,
     description="6-digit Multi Factor Authentication key, generated by google authenticator or similar",
     arg_type=str,
     example=["571208", "222104"],
@@ -175,6 +177,53 @@ ARG_RES__mfa_key = SwaggerArgumentResponse(
     condition="MFA is turned on"
 )
 
+DOCUMENTATION__login_details = SwaggerDocumentation(
+    tags="Login Details",
+    security=False,
+    methods=SwaggerMethod(
+        name="Fetch Login Fields",
+        description="Fetches the fields that are required to login",
+        method=REST__GET,
+        response=SwaggerResponse(
+            description="A response detailing what fields are required to login",
+            response=SwaggerSimpleList(
+                arg_type=str,
+                description="A list of fields required to login",
+                example=[KEY__username, KEY__password, KEY__mfa_key],
+                required=True
+            )
+        )
+    )
+)
+
+EXAMPLE__application_name = "Library Browser"
+EXAMPLE__application_url = "https://jaaql.com/demos/library-application"
+
+ARG_RES__application_name = SwaggerArgumentResponse(
+    name=KEY__application_name,
+    description="Application name",
+    arg_type=str,
+    example=[EXAMPLE__application_name, "Meeting Room Scheduling Assistant"],
+    required=True
+)
+ARG_RES__application_description = SwaggerArgumentResponse(
+    name="description",
+    description="Application description",
+    arg_type=str,
+    example=["Browses books in the library", "Helps book meetings"],
+    required=True
+)
+ARG_RES__application_uri = SwaggerArgumentResponse(
+    name=KEY__application_url,
+    description="Application url. Please use '{{DEFAULT}}/myappurl' if you want to host it in the same place as jaaql. "
+    "For example '{{DEFAULT}}/console' would be the URL for the console",
+    arg_type=str,
+    example=[EXAMPLE__application_url, "https://jaaql.com/demos/meeting-application"],
+    required=True
+)
+
+ARG_RES__application_body = [ARG_RES__application_name, ARG_RES__application_description, ARG_RES__application_uri]
+
 DOCUMENTATION__oauth_token = SwaggerDocumentation(
     tags="OAuth",
     security=False,  # This _is_ the security method, therefore it is not expecting a jwt token
